🎉 Thank you for your interest in contributing to PyPSA! 🎉

We strongly welcome anyone interested in contributing to PyPSA and it's related projects. All types of contributions are encouraged and valued!

Detailed guidelines can be found in the [Contributing](https://pypsa.readthedocs.io/en/latest/contributing.html) section of our documentation.
